@@ -1,5 +1,13 @@
-from .running.runner import main
+from .running.runner import (
+    main,
+    ApiConfig,
+    WebConfig,
+    AppConfig,
+    SonicConfig,
+    OcrConfig
+)
 from .running.conf import App
+from .page import Page
 from .utils.config import FileConfig
 from .utils.pytest_util import *
 from .utils.allure_util import *
@@ -9,7 +17,6 @@ from .core.adr import AdrTC, AdrElem
 from .core.ios import IosTC, IosElem
 from .core.web import WebTC, WebElem
 from .core.hm import HmTC, HmElem
-from .page import Page
 
-__version__ = "0.2.0"
+__version__ = "0.2.8"
 __description__ = "API/安卓/IOS/WEB/鸿蒙Next平台自动化测试框架"
